@@ -1,6 +1,7 @@
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import,unused-argument,super-init-not-called
 """
-Main interface for pi service client
+Type annotations for pi service client.
+
+[Open documentation](./client.md)
 
 Usage::
 
@@ -17,7 +18,7 @@ from typing import Any, Dict, List, Type
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_pi.type_defs import (
+from .type_defs import (
     DescribeDimensionKeysResponseTypeDef,
     DimensionGroupTypeDef,
     GetResourceMetricsResponseTypeDef,
@@ -50,7 +51,8 @@ class Exceptions:
 
 class PIClient:
     """
-    [PI.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.17/reference/services/pi.html#PI.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/pi.html#PI.Client)
+    [Show boto3-stubs documentation](./client.md)
     """
 
     meta: ClientMeta
@@ -58,7 +60,8 @@ class PIClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.17/reference/services/pi.html#PI.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/pi.html#PI.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def describe_dimension_keys(
@@ -76,7 +79,8 @@ class PIClient:
         NextToken: str = None,
     ) -> DescribeDimensionKeysResponseTypeDef:
         """
-        [Client.describe_dimension_keys documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.17/reference/services/pi.html#PI.Client.describe_dimension_keys)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/pi.html#PI.Client.describe_dimension_keys)
+        [Show boto3-stubs documentation](./client.md#describe_dimension_keys)
         """
 
     def generate_presigned_url(
@@ -87,7 +91,8 @@ class PIClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.17/reference/services/pi.html#PI.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/pi.html#PI.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_resource_metrics(
@@ -102,5 +107,6 @@ class PIClient:
         NextToken: str = None,
     ) -> GetResourceMetricsResponseTypeDef:
         """
-        [Client.get_resource_metrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.17/reference/services/pi.html#PI.Client.get_resource_metrics)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.81/reference/services/pi.html#PI.Client.get_resource_metrics)
+        [Show boto3-stubs documentation](./client.md#get_resource_metrics)
         """
