@@ -1,5 +1,7 @@
 """
-Main interface for pi service type definitions.
+Type annotations for pi service type definitions.
+
+[Open documentation](./type_defs.md)
 
 Usage::
 
@@ -21,58 +23,24 @@ else:
 
 __all__ = (
     "DataPointTypeDef",
+    "DescribeDimensionKeysResponseTypeDef",
     "DimensionGroupTypeDef",
     "DimensionKeyDescriptionTypeDef",
+    "GetResourceMetricsResponseTypeDef",
     "MetricKeyDataPointsTypeDef",
+    "MetricQueryTypeDef",
     "ResponsePartitionKeyTypeDef",
     "ResponseResourceMetricKeyTypeDef",
-    "DescribeDimensionKeysResponseTypeDef",
-    "GetResourceMetricsResponseTypeDef",
-    "MetricQueryTypeDef",
 )
 
-DataPointTypeDef = TypedDict("DataPointTypeDef", {"Timestamp": datetime, "Value": float})
-
-_RequiredDimensionGroupTypeDef = TypedDict("_RequiredDimensionGroupTypeDef", {"Group": str})
-_OptionalDimensionGroupTypeDef = TypedDict(
-    "_OptionalDimensionGroupTypeDef", {"Dimensions": List[str], "Limit": int}, total=False
+DataPointTypeDef = TypedDict(
+    "DataPointTypeDef",
+    {
+        "Timestamp": datetime,
+        "Value": float,
+    },
 )
 
-
-class DimensionGroupTypeDef(_RequiredDimensionGroupTypeDef, _OptionalDimensionGroupTypeDef):
-    pass
-
-
-DimensionKeyDescriptionTypeDef = TypedDict(
-    "DimensionKeyDescriptionTypeDef",
-    {"Dimensions": Dict[str, str], "Total": float, "Partitions": List[float]},
-    total=False,
-)
-
-MetricKeyDataPointsTypeDef = TypedDict(
-    "MetricKeyDataPointsTypeDef",
-    {"Key": "ResponseResourceMetricKeyTypeDef", "DataPoints": List["DataPointTypeDef"]},
-    total=False,
-)
-
-ResponsePartitionKeyTypeDef = TypedDict(
-    "ResponsePartitionKeyTypeDef", {"Dimensions": Dict[str, str]}
-)
-
-_RequiredResponseResourceMetricKeyTypeDef = TypedDict(
-    "_RequiredResponseResourceMetricKeyTypeDef", {"Metric": str}
-)
-_OptionalResponseResourceMetricKeyTypeDef = TypedDict(
-    "_OptionalResponseResourceMetricKeyTypeDef", {"Dimensions": Dict[str, str]}, total=False
-)
-
-
-class ResponseResourceMetricKeyTypeDef(
-    _RequiredResponseResourceMetricKeyTypeDef, _OptionalResponseResourceMetricKeyTypeDef
-):
-    pass
-
-
 DescribeDimensionKeysResponseTypeDef = TypedDict(
     "DescribeDimensionKeysResponseTypeDef",
     {
@@ -85,6 +53,36 @@ DescribeDimensionKeysResponseTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredDimensionGroupTypeDef = TypedDict(
+    "_RequiredDimensionGroupTypeDef",
+    {
+        "Group": str,
+    },
+)
+_OptionalDimensionGroupTypeDef = TypedDict(
+    "_OptionalDimensionGroupTypeDef",
+    {
+        "Dimensions": List[str],
+        "Limit": int,
+    },
+    total=False,
+)
+
+
+class DimensionGroupTypeDef(_RequiredDimensionGroupTypeDef, _OptionalDimensionGroupTypeDef):
+    pass
+
+
+DimensionKeyDescriptionTypeDef = TypedDict(
+    "DimensionKeyDescriptionTypeDef",
+    {
+        "Dimensions": Dict[str, str],
+        "Total": float,
+        "Partitions": List[float],
+    },
+    total=False,
+)
+
 GetResourceMetricsResponseTypeDef = TypedDict(
     "GetResourceMetricsResponseTypeDef",
     {
@@ -97,13 +95,58 @@ GetResourceMetricsResponseTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredMetricQueryTypeDef = TypedDict("_RequiredMetricQueryTypeDef", {"Metric": str})
+MetricKeyDataPointsTypeDef = TypedDict(
+    "MetricKeyDataPointsTypeDef",
+    {
+        "Key": "ResponseResourceMetricKeyTypeDef",
+        "DataPoints": List["DataPointTypeDef"],
+    },
+    total=False,
+)
+
+_RequiredMetricQueryTypeDef = TypedDict(
+    "_RequiredMetricQueryTypeDef",
+    {
+        "Metric": str,
+    },
+)
 _OptionalMetricQueryTypeDef = TypedDict(
     "_OptionalMetricQueryTypeDef",
-    {"GroupBy": "DimensionGroupTypeDef", "Filter": Dict[str, str]},
+    {
+        "GroupBy": "DimensionGroupTypeDef",
+        "Filter": Dict[str, str],
+    },
     total=False,
 )
 
 
 class MetricQueryTypeDef(_RequiredMetricQueryTypeDef, _OptionalMetricQueryTypeDef):
     pass
+
+
+ResponsePartitionKeyTypeDef = TypedDict(
+    "ResponsePartitionKeyTypeDef",
+    {
+        "Dimensions": Dict[str, str],
+    },
+)
+
+_RequiredResponseResourceMetricKeyTypeDef = TypedDict(
+    "_RequiredResponseResourceMetricKeyTypeDef",
+    {
+        "Metric": str,
+    },
+)
+_OptionalResponseResourceMetricKeyTypeDef = TypedDict(
+    "_OptionalResponseResourceMetricKeyTypeDef",
+    {
+        "Dimensions": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class ResponseResourceMetricKeyTypeDef(
+    _RequiredResponseResourceMetricKeyTypeDef, _OptionalResponseResourceMetricKeyTypeDef
+):
+    pass
